@@ -4,7 +4,7 @@
 //! ```
 //! extern crate keepass;
 //!
-//! use keepass::{Database, Node, Result, Error};
+//! use keepass::{Database, NodeRef, Result, Error};
 //! use std::fs::File;
 //!
 //! fn main() -> Result<()> {
@@ -15,10 +15,10 @@
 //!     // Iterate over all Groups and Nodes
 //!     for node in &db.root {
 //!         match node {
-//!             Node::Group(g) => {
+//!             NodeRef::Group(g) => {
 //!                 println!("Saw group '{0}'", g.name);
 //!             },
-//!             Node::Entry(e) => {
+//!             NodeRef::Entry(e) => {
 //!                 let title = e.get_title().unwrap();
 //!                 let user = e.get_username().unwrap();
 //!                 let pass = e.get_password().unwrap();
@@ -33,22 +33,7 @@
 
 #![recursion_limit = "1024"]
 
-extern crate aes;
-extern crate argon2;
-extern crate base64;
-extern crate block_modes;
-extern crate byteorder;
-extern crate chacha20;
-extern crate flate2;
-extern crate hex_literal;
-extern crate hmac;
-extern crate indexmap;
-extern crate salsa20;
-extern crate secstr;
-extern crate sha2;
-extern crate stream_cipher;
-extern crate xml;
-
+mod config;
 mod crypt;
 mod db;
 mod decompress;
